package com.ynet.life.loaf.action;

import com.ynet.gene.core.Context;
import com.ynet.gene.core.GENEException;
import com.ynet.life.action.LifeJDBCAction;
import com.ynet.life.base.LifeDBAccess;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.loaf.LoafTools;
import com.ynet.life.loaf.jdbc.LoafQueryFactory;
import com.ynet.life.loaf.jdbc.LoafQueryInterface;
import java.sql.Connection;
import java.sql.PreparedStatement;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.util.ArrayList;
import java.util.LinkedList;
import java.util.List;
import java.util.StringTokenizer;

/* loaded from: com_ynet_life_loaf_action.jar:com/ynet/life/loaf/action/QueryDataDetailUsingSQLAction.class */
public class QueryDataDetailUsingSQLAction extends LifeJDBCAction {
    private static final String FIELD_SEPERATOR = "||";
    private String querySql;
    private List outputFields = new ArrayList();
    private String sortParam;
    private static final String ERROR_CODE_POOL = "EBLN0011";

    public String execute(Context context) throws GENEException {
        if (this.querySql != null) {
            try {
                if (!"".equals(this.querySql)) {
                    try {
                        List input = new LinkedList();
                        String finalSQL = LoafTools.parseQuerySql(context, this.querySql, input);
                        LoafQueryInterface query = LoafQueryFactory.getNewQuery("", this.sortParam, finalSQL);
                        PreparedStatement ps = null;
                        ResultSet resultSet = null;
                        try {
                            try {
                                Connection connection = LifeDBAccess.getConnection(getDataSource());
                                ps = query.getQueryStatement(connection, input);
                                resultSet = ps.executeQuery();
                                int dateSize = this.outputFields.size();
                                if (resultSet.next()) {
                                    for (int i = 1; i <= dateSize; i++) {
                                        String dataFieldValue = resultSet.getString(i);
                                        context.put((String) this.outputFields.get(i - 1), dataFieldValue);
                                        Trace.logDebug("LOAF", "输出参数--->\n".concat(String.valueOf(dataFieldValue)));
                                    }
                                    if (resultSet.next()) {
                                        throw new TranFailException("EBLN0000", "在数据库中查询到多条记录");
                                    }
                                    LifeDBAccess.cleanResources(ps, resultSet);
                                    LifeDBAccess.releaseConnection(getDataSource(), connection);
                                    return "0";
                                }
                                Trace.logWarn("LifeJDBC", "在数据库中未查询到相关记录,请检查查询SQL语句");
                                LifeDBAccess.releaseConnection(getDataSource(), connection);
                                return QueryDataListAction.NO_DATA_FOUND;
                            } finally {
                                LifeDBAccess.cleanResources(ps, resultSet);
                            }
                        } catch (SQLException ex) {
                            throw new TranFailException("EBLN0000", ex);
                        }
                    } catch (GENEException empe) {
                        Trace.logError("LOAF", empe.getMessage(), empe);
                        throw empe;
                    }
                }
            } catch (Throwable th) {
                LifeDBAccess.releaseConnection(getDataSource(), (Connection) null);
                throw th;
            }
        }
        throw new TranFailException(ERROR_CODE_POOL, "查询sql语句不能为空");
    }

    public void setSortParam(String sortParam) {
        this.sortParam = sortParam;
    }

    public void setOutputFields(String outputFields) {
        StringTokenizer toke = new StringTokenizer(outputFields, FIELD_SEPERATOR);
        while (toke.hasMoreElements()) {
            String input = ((String) toke.nextElement()).trim();
            this.outputFields.add(input);
        }
    }

    public void setQuerySql(String querySql) {
        this.querySql = querySql;
    }
}
